smtfuzz: A random generator for SMT-LIB2 formulas
====================================================


Just type `smtfuzz`, and you will see an SMT-LIB2 formula in the screen.


For more advanced options, please try `smtfuzz -h`
